Governing Equations
===================

The classes here correspond to the three governing equations.

Overview
--------

.. currentmodule:: pylcp

.. autosummary::

    governingeq.governingeq
    heuristiceq
    rateeq
    obe

Details
-------

.. autoclass:: pylcp.governingeq.governingeq
  :members:

.. autoclass:: pylcp.heuristiceq
  :members:

.. autoclass:: pylcp.common.base_force_profile
  :members:

.. autoclass:: pylcp.rateeq
  :members:

.. autoclass:: pylcp.rateeq.force_profile
  :members:

.. autoclass:: pylcp.obe
  :members:

.. autoclass:: pylcp.obe.force_profile
  :members:
